@@ -1,5 +1,7 @@
+from .b_madara_wp import MadaraBase
 from .b_mangastream_wp import MangaStreamBase
 
 __all__ = [
+    MadaraBase,
     MangaStreamBase
 ]
